@@ -2,7 +2,7 @@ import re
 from urllib import unquote
 from urlparse import urljoin
 from datetime import datetime
-from sha import sha
+from hashlib import sha1
 import operator
 
 from webob import Request, Response
@@ -33,7 +33,8 @@ class JSONStore(object):
 
     def __call__(self, environ, start_response):
         req = Request(environ)
-        func = getattr(self, req.method)
+        method = req.GET.get('method') or req.method
+        func = getattr(self, method)
         res = func(req)
         return res(environ, start_response)
 
@@ -55,8 +56,8 @@ class JSONStore(object):
             except (IndexError, KeyError):
                 return Response(status='404 Not Found')
 
-        body = dumps(result, cls=DatetimeEncoder)
-        etag = '"%s"' % sha(body).hexdigest()
+        body = dumps(result, cls=DatetimeEncoder, indent=4)
+        etag = '"%s"' % sha1(body).hexdigest()
         if etag in req.if_none_match:
             return Response(status='304 Not Modified')
 
@@ -84,8 +85,8 @@ class JSONStore(object):
             result = self.em.create(entry)
         except ConflictError:
             return Response(status='409 Conflict')
-        body = dumps(result, cls=DatetimeEncoder)
-        etag = '"%s"' % sha(body).hexdigest()
+        body = dumps(result, cls=DatetimeEncoder, indent=4)
+        etag = '"%s"' % sha1(body).hexdigest()
         location = urljoin(req.application_url, result['__id__'])
 
         return Response(
@@ -105,7 +106,7 @@ class JSONStore(object):
 
         # Conditional PUT. This is useful for implementing counters, eg.
         def condition(old):
-            etag = '%s' % sha(dumps(old, cls=DatetimeEncoder)).hexdigest()  # no quotes to check against req.if_match
+            etag = '%s' % sha1(dumps(old, cls=DatetimeEncoder, indent=4)).hexdigest()  # no quotes to check against req.if_match
             return etag in req.if_match or (
                     req.if_unmodified_since and 
                     req.if_unmodified_since >= old['__updated__'])
@@ -114,8 +115,8 @@ class JSONStore(object):
         except ConflictError:
             return Response(status='412 Precondition Failed')
 
-        body = dumps(result, cls=DatetimeEncoder)
-        etag = '"%s"' % sha(body).hexdigest()
+        body = dumps(result, cls=DatetimeEncoder, indent=4)
+        etag = '"%s"' % sha1(body).hexdigest()
 
         return Response(
                 body=body,
@@ -140,7 +141,7 @@ def load_entry(s):
     except ValueError:
         try:
             entry = rison.loads(s)
-        except rison.ParserException:
+        except (ValueError, rison.ParserException):
             entry = s
     return entry
 
