@@ -78,15 +78,22 @@ class EntryManager(object):
         entry.setdefault('__updated__', datetime_to_iso(datetime.utcnow()))
 
         # Store entry.
-        self.index_entry(entry)
+        self.store_entry(entry)
         return entry
 
-    def delete(self, key):
-        self.conn.execute("""
-            DELETE FROM flat
-            WHERE id=?;
-        """, (key,))
-        self.conn.commit()
+    def delete(self, obj=None, **kwargs):
+        if obj is None:
+            obj = kwargs
+
+        if isinstance(obj, dict):
+            entries = self.search(obj)
+            keys = [entry['__id__'] for entry in entries]
+        else:
+            keys = [key]
+
+        for id_ in keys:
+            with self.lock[id_]:
+                self.delete_entry(id_)
 
     def update(self, entry=None, condition=lambda old: True, **kwargs): 
         if entry is None:
@@ -100,7 +107,7 @@ class EntryManager(object):
             old = self.load_entry(id_)
             if not condition(old):
                 raise ConflictError("Pre-condition failed!")
-            self.delete(id_)
+            self.delete_entry(id_)
             new = self.create(entry)
         return new
 
@@ -183,7 +190,7 @@ class EntryManager(object):
         """, (id_,))
         return loads(curs.fetchone()[0])
 
-    def index_entry(self, entry):
+    def store_entry(self, entry):
         # Index entry.
         indexes = [(entry['__id__'], entry['__updated__'], k, v)
                 for (k, v) in flatten(entry) if k != '__id__']
@@ -197,6 +204,11 @@ class EntryManager(object):
         """, (entry['__id__'], dumps(entry)))
         self.conn.commit()
 
+    def delete_entry(self, id_):
+        self.conn.execute("DELETE FROM flat WHERE id=?;", (id_,))
+        self.conn.execute("DELETE FROM store WHERE id=?;", (id_,))
+        self.conn.commit()
+
     def close(self):
         self.conn.close()
         del LOCAL.conns[self.index]
